/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/

package com.ael.util;

import java.sql.Connection;
import java.sql.Statement;
import java.sql.ResultSet;

import org.experlog.openeas.api.Session;

/**
 * Classe permettant la génération automatique de numéros de partenaires (clients
 * et prospects).
 * 
 * @author jm
 */
public class GenNumPartenaire {
	
	private Connection conn;
	private String baseFact;
	private String baseCrm;
	
	/**
	 * Constructeur pour objet <code>GenNumPartenaire</code>
	 * 
	 * @param	session				session sous forme de chaîne identifiante
	 */
	public GenNumPartenaire(String session) {
		
		try {
			Session s = Session.findClient(session);
			baseFact = s.getCookie().get("BaseDossier");
			baseCrm = s.getCookie().get("CRMDossier");
			conn = s.getConnection(null);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * Calculer un identifiant prospect à partir du dernier inséré dans la base
	 * pour un département donné.
	 * 
	 * @param	codePostal	chaîne de code postal de la ville du prospect
	 * @return l'identifiant prospect formaté P<num département><num ordre>, ou chaîne vide si erreur
	 */
	public String genIdentifiantProspect(String codePostal) {
		try {
			String numDept = codePostal.substring(0, 2);
			Statement stmt = conn.createStatement();
			ResultSet rs = stmt.executeQuery("SELECT COALESCE(MAX(Id_Prospect), '') AS maxId FROM " + baseCrm + ".PROSPECT " +
											  "WHERE SUBSTRING(Id_Prospect, 1, 3) = 'P" + numDept + "'");
			rs.next();
			String idProspect = rs.getString("maxId");
			int val = (idProspect.equals("") ? 0 : Integer.parseInt(idProspect.substring(3, idProspect.length()), 10) + 1);
			return "P" + numDept + String.format("%1$05d", val);
		} catch (Exception e) {
			return "";
		}
		
	}
	
	/**
	 * Calculer un identifiant client à partir du dernier inséré dans la base
	 * pour un département donné.
	 * 
	 * @param	codePostal	chaîne de code postal de la ville du client
	 * @return l'identifiant client formaté C<num département><num ordre>, ou chaîne vide si erreur
	 */
	public String genIdentifiantClient(String codePostal) {
		try {
			String numDept = codePostal.substring(0, 2);
			Statement stmt = conn.createStatement();
			ResultSet rs = stmt.executeQuery("SELECT COALESCE(MAX(Client_Id), '') AS maxId FROM " + baseFact + ".FICHE_CLIENT " +
											  "WHERE SUBSTRING(Client_Id, 1, 3) = 'C" + numDept + "'");
			rs.next();
			String idClient= rs.getString("maxId");
			int val = (idClient.equals("") ? 0 : Integer.parseInt(idClient.substring(3, idClient.length()), 10) + 1);
			return "C" + numDept + String.format("%1$04d", val);
		} catch (Exception e) {
			return "";
		}
	}

}
